@@ -1,251 +1,30 @@
-# Palm::Datebook.pm
-# 
-# Perl class for dealing with Palm DateBook and Calendar databases. 
+package Palm::Datebook;
+#
+# ABSTRACT: Handler for Palm OS DateBook and Calendar databases
 #
 #	Copyright (C) 1999-2001, Andrew Arensburger.
-#	You may distribute this file under the terms of the Artistic
-#	License, as specified in the README file.
+#
+# This program is free software; you can redistribute it and/or modify
+# it under the same terms as Perl itself.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See either the
+# GNU General Public License or the Artistic License for more details.
 
 use strict;
-package Palm::Datebook;
 use Palm::Raw();
 use Palm::StdAppInfo();
 
 use vars qw( $VERSION @ISA );
 
 # One liner, to allow MakeMaker to work.
-$VERSION = '1.013';
+$VERSION = '1.014';
+# This file is part of Palm 1.014 (August 2, 2014)
 
 @ISA = qw( Palm::StdAppInfo Palm::Raw );
 
 
-=head1 NAME
-
-Palm::Datebook - Handler for Palm DateBook and Calendar databases.
-
-=head1 SYNOPSIS
-
-    use Palm::Datebook;
-
-=head1 DESCRIPTION
-
-The Datebook PDB handler is a helper class for the Palm::PDB package.
-It parses DateBook and Calendar databases.
-
-=head2 AppInfo block
-
-The AppInfo block begins with standard category support. See
-L<Palm::StdAppInfo> for details.
-
-=head2 Sort block
-
-    $pdb->{sort}
-
-This is a scalar, the raw data of the sort block.
-
-=head2 Records
-
-    $record = $pdb->{records}[N]
-
-    $record->{day}
-    $record->{month}
-    $record->{year}
-
-The day, month and year of the event. The day and month start at 1
-(I<i.e.>, for January, C<< $record->{month} >> is set to 1). The year
-is a four-digit number (for dates in 2001, C<< $record->{year} >> is
-"2001").
-
-For repeating events, these fields specify the first date at which the
-event occurs.
-
-    $record->{start_hour}
-    $record->{start_minute}
-    $record->{end_hour}
-    $record->{end_minute}
-
-The start and end times of the event. For untimed events, all of these
-are 0xff.
-
-    $record->{when_changed}
-
-This is defined and true iff the "when info" for the record has
-changed. I don't know what this means.
-
-    $record->{alarm}{advance}
-    $record->{alarm}{unit}
-
-If the record has an alarm associated with it, the
-%{$record->{alarm}} hash exists. The "unit" subfield is an integer:
-0 for minutes, 1 for hours, 2 for days. The "advance" subfield
-specifies how many units before the event the alarm should ring.
-I<e.g.>, if "unit" is 1 and "advance" is 5, then the alarm will sound
-5 hours before the event.
-
-If C<advance> is -1, then there is no alarm associated with this event.
-New records created via C<new_Record> have a 10 minute alarm set by
-default. C<< undef $record->{alarm} >> to remove this alarm before writing.
-An alarm icon will still show up in the Datebook if the C<alarm>
-field exists, even with C<advance> set to -1.
-
-    %{$record->{repeat}}
-
-This exists iff this is a repeating event.
-
-    $record->{repeat}{type}
-
-An integer which specifies the type of repeat:
-
-=over 4
-
-=item 0
-
-no repeat.
-
-=item 1Z<>
-
-a daily event, one that occurs every day.
-
-=item 2Z<>
-
-a weekly event, one that occurs every week on the same dayZ<>(s). An
-event may occur on several days every week, I<e.g.>, every Monday,
-Wednesday and Friday.
-
-For weekly events, the following fields are defined:
-
-    @{$record->{repeat}{repeat_days}}
-
-This is an array of 7 elements; each element is true iff the event
-occurs on the corresponding day. Element 0 is Sunday, element 1 is
-Monday, and so forth.
-
-    $record->{repeat}{start_of_week}
-
-Day the week starts on (0 for Sunday, 1 for Monday). This affects
-the phase of events that repeat every 2nd (or more) Sunday.
-
-=item 3Z<>
-
-a "monthly by day" event, I<e.g.>, one that occurs on the second
-Friday of every month.
-
-For "monthly by day" events, the following fields are defined:
-
-    $record->{repeat}{weeknum}
-
-The number of the week on which the event occurs. 0 means the first
-week of the month, 1 means the second week of the month, and so forth.
-A value of 5 means that the event occurs on the last week of the
-month.
-
-    $record->{repeat}{daynum}
-
-An integer, the day of the week on which the event occurs. 0 means
-Sunday, 1 means Monday, and so forth.
-
-=item 4Z<>
-
-a "monthly by date" event, I<e.g.>, one that occurs on the 12th of
-every month.
-
-=item 5Z<>
-
-a yearly event, I<e.g.>, one that occurs every year on December 25th.
-
-    $record->{repeat}{frequency}
-
-Specifies the frequency of the repeat. For instance, if the event is a
-daily one, and $record->{repeat}{frequency} is 3, then the event
-occurs every 3 days.
-
-=back
-
-    $record->{repeat}{unknown}
-
-I don't know what this is.
-
-    $record->{repeat}{end_day}
-    $record->{repeat}{end_month}
-    $record->{repeat}{end_year}
-
-The last day, month and year on which the event occurs.
-
-    @{$record->{exceptions}}
-    $day   = $record->{exceptions}[N][0]
-    $month = $record->{exceptions}[N][1]
-    $year  = $record->{exceptions}[N][2]
-
-If there are any exceptions to a repeating event, I<e.g.> a weekly
-meeting that was cancelled one time, then the
-@{$record->{exceptions}} array is defined.
-
-Each element in this array is a reference to an anonymous array with
-three elements: the day, month, and year of the exception.
-
-    $record->{description}
-
-A text string, the description of the event.
-
-    $record->{location}
-
-A text string, the location (if any) of the event (Calendar database only).
-
-    $record->{note}
-
-A text string, the note (if any) attached to the event.
-
-    %{$record->{timezone}}
-
-This exists iff a time zone has been set for the event.
-
-    $record->{timezone}{name}
-
-The time zone name, I<e.g.>, "London" or "San Francisco".
-
-    $record->{timezone}{country}
-
-The country the time zone is in. This is an integer defined in Core/System/PalmLocale.h.
-
-    $record->{timezone}{offset}
-
-This gives the offset from UTC, in minutes, of the time zone.
-
-    $record->{timezone}{dst_adjustment}
-
-This gives the additional offset while daylight savings time is in effect.
-The offset from UTC is $record->{timezone}{offset} + $record->{timezone}{dst_adjustment}
-(actually only 0 or 60 are used).
-
-    $record->{timezone}{custom}
-
-Should indicate whether this location was created by the user, though this
-always seems to be true.
-
-    $record->{timezone}{flags}
-
-Reserved flags.
-
-    $record->{timezone}{start_hour}
-    $record->{timezone}{start_daynum}
-    $record->{timezone}{start_weeknum}
-    $record->{timezone}{start_month}
-    $record->{timezone}{end_hour}
-    $record->{timezone}{end_daynum}
-    $record->{timezone}{end_weeknum}
-    $record->{timezone}{end_month}
-
-These define the period during which daylight savings time is in effect
-if $record->{timezone}{dst_adjustment} is non-zero.
-daynum specifies the day of week (0=Sunday, 6=Saturday) and weeknum specifies the week of month
-(0=1st, 3=4th, 4=last), analagously to the "monthly by day" repeating event.
-I<e.g.>, The "London" time zone has DST starting on the last Sunday of March, which
-is indicated with start_daynum=0 (Sunday), start_weeknum=4 (last week of the month),
-and start_month=3 (March).
-
-=head1 METHODS
-
-=cut
 #'
 
 sub import
@@ -256,16 +35,6 @@ sub import
 		);
 }
 
-=head2 new
-
-  $pdb = new Palm::Datebook;
-  $pdb = new Palm::Datebook({app => 'Calendar'});
-
-Create a new PDB, initialized with the various Palm::Datebook fields
-and an empty record list. Creates a Datebook PDB by default.
-Specify the app parameter as 'Calendar' to create a Calendar PDB.
-
-=cut
 #'
 
 # new
@@ -302,16 +71,6 @@ sub new
 	return $self;
 }
 
-=head2 new_Record
-
-  $record = $pdb->new_Record;
-
-Creates a new Datebook record, with blank values for all of the fields.
-
-C<new_Record> does B<not> add the new record to C<$pdb>. For that,
-you want C<< $pdb->append_Record >>.
-
-=cut
 
 sub new_Record
 {
@@ -632,10 +391,10 @@ sub PackRecord
 	# XXX - Better to collect data first, then build flags.
 	$flags = $record->{other_flags};
 #  	$flags |= 0x8000 if $record->{when_changed};
-#  	$flags |= 0x4000 if keys %{$record->{alarm}} ne ();
-#  	$flags |= 0x2000 if keys %{$record->{repeat}} ne ();
+#  	$flags |= 0x4000 if keys %{$record->{alarm} } ne ();
+#  	$flags |= 0x2000 if keys %{$record->{repeat} } ne ();
 #  	$flags |= 0x1000 if $record->{note} ne "";
-#  	$flags |= 0x0800 if $#{$record->{exceptions}} >= 0;
+#  	$flags |= 0x0800 if $#{$record->{exceptions} } >= 0;
 #  	$flags |= 0x0400 if $record->{description} ne "";
 #  	$flags |= 0x0200 if $iscal && $record->{location} ne "";
 
@@ -802,24 +561,319 @@ sub PackRecord
 }
 
 1;
+
 __END__
 
-=head1 SOURCE CONTROL
+=head1 NAME
 
-The source is in Github:
+Palm::Datebook - Handler for Palm OS DateBook and Calendar databases
 
-	http://github.com/briandfoy/p5-Palm/tree/master
-	
-=head1 AUTHOR
+=head1 VERSION
 
-Alessandro Zummo, C<< <a.zummo@towertech.it> >>
+This document describes version 1.014 of
+Palm::Datebook, released August 2, 2014
+as part of Palm version 1.014.
 
-Currently maintained by brian d foy, C<< <bdfoy@cpan.org> >>
+=head1 SYNOPSIS
+
+    use Palm::Datebook;
+
+=head1 DESCRIPTION
+
+The Datebook PDB handler is a helper class for the Palm::PDB package.
+It parses DateBook and Calendar databases.
+
+=head2 AppInfo block
+
+The AppInfo block begins with standard category support. See
+L<Palm::StdAppInfo> for details.
+
+=head2 Sort block
+
+    $pdb->{sort}
+
+This is a scalar, the raw data of the sort block.
+
+=head2 Records
+
+    $record = $pdb->{records}[N]
+
+    $record->{day}
+    $record->{month}
+    $record->{year}
+
+The day, month and year of the event. The day and month start at 1
+(I<i.e.>, for January, C<< $record->{month} >> is set to 1). The year
+is a four-digit number (for dates in 2001, C<< $record->{year} >> is
+"2001").
+
+For repeating events, these fields specify the first date at which the
+event occurs.
+
+    $record->{start_hour}
+    $record->{start_minute}
+    $record->{end_hour}
+    $record->{end_minute}
+
+The start and end times of the event. For untimed events, all of these
+are 0xff.
+
+    $record->{when_changed}
+
+This is defined and true iff the "when info" for the record has
+changed. I don't know what this means.
+
+    $record->{alarm}{advance}
+    $record->{alarm}{unit}
+
+If the record has an alarm associated with it, the
+%{$record->{alarm}Z<>} hash exists. The "unit" subfield is an integer:
+0 for minutes, 1 for hours, 2 for days. The "advance" subfield
+specifies how many units before the event the alarm should ring.
+I<e.g.>, if "unit" is 1 and "advance" is 5, then the alarm will sound
+5 hours before the event.
+
+If C<advance> is -1, then there is no alarm associated with this event.
+New records created via C<new_Record> have a 10 minute alarm set by
+default. C<< undef $record->{alarm} >> to remove this alarm before writing.
+An alarm icon will still show up in the Datebook if the C<alarm>
+field exists, even with C<advance> set to -1.
+
+    %{ $record->{repeat} }
+
+This exists iff this is a repeating event.
+
+    $record->{repeat}{type}
+
+An integer which specifies the type of repeat:
+
+=over 4
+
+=item 0
+
+no repeat.
+
+=item 1Z<>
+
+a daily event, one that occurs every day.
+
+=item 2Z<>
+
+a weekly event, one that occurs every week on the same dayZ<>(s). An
+event may occur on several days every week, I<e.g.>, every Monday,
+Wednesday and Friday.
+
+For weekly events, the following fields are defined:
+
+    @{ $record->{repeat}{repeat_days} }
+
+This is an array of 7 elements; each element is true iff the event
+occurs on the corresponding day. Element 0 is Sunday, element 1 is
+Monday, and so forth.
+
+    $record->{repeat}{start_of_week}
+
+Day the week starts on (0 for Sunday, 1 for Monday). This affects
+the phase of events that repeat every 2nd (or more) Sunday.
+
+=item 3Z<>
+
+a "monthly by day" event, I<e.g.>, one that occurs on the second
+Friday of every month.
+
+For "monthly by day" events, the following fields are defined:
+
+    $record->{repeat}{weeknum}
+
+The number of the week on which the event occurs. 0 means the first
+week of the month, 1 means the second week of the month, and so forth.
+A value of 5 means that the event occurs on the last week of the
+month.
+
+    $record->{repeat}{daynum}
+
+An integer, the day of the week on which the event occurs. 0 means
+Sunday, 1 means Monday, and so forth.
+
+=item 4Z<>
+
+a "monthly by date" event, I<e.g.>, one that occurs on the 12th of
+every month.
+
+=item 5Z<>
+
+a yearly event, I<e.g.>, one that occurs every year on December 25th.
+
+    $record->{repeat}{frequency}
+
+Specifies the frequency of the repeat. For instance, if the event is a
+daily one, and $record->{repeat}{frequency} is 3, then the event
+occurs every 3 days.
+
+=back
+
+    $record->{repeat}{unknown}
+
+I don't know what this is.
+
+    $record->{repeat}{end_day}
+    $record->{repeat}{end_month}
+    $record->{repeat}{end_year}
+
+The last day, month and year on which the event occurs.
+
+    @{ $record->{exceptions} }
+    $day   = $record->{exceptions}[N][0]
+    $month = $record->{exceptions}[N][1]
+    $year  = $record->{exceptions}[N][2]
+
+If there are any exceptions to a repeating event, I<e.g.> a weekly
+meeting that was cancelled one time, then the
+@{$record->{exceptions}Z<>} array is defined.
+
+Each element in this array is a reference to an anonymous array with
+three elements: the day, month, and year of the exception.
+
+    $record->{description}
+
+A text string, the description of the event.
+
+    $record->{location}
+
+A text string, the location (if any) of the event (Calendar database only).
+
+    $record->{note}
+
+A text string, the note (if any) attached to the event.
+
+    %{ $record->{timezone} }
+
+This exists iff a time zone has been set for the event.
+
+    $record->{timezone}{name}
+
+The time zone name, I<e.g.>, "London" or "San Francisco".
+
+    $record->{timezone}{country}
+
+The country the time zone is in. This is an integer defined in Core/System/PalmLocale.h.
+
+    $record->{timezone}{offset}
+
+This gives the offset from UTC, in minutes, of the time zone.
+
+    $record->{timezone}{dst_adjustment}
+
+This gives the additional offset while daylight savings time is in effect.
+The offset from UTC is $record->{timezone}{offset} + $record->{timezone}{dst_adjustment}
+(actually only 0 or 60 are used).
+
+    $record->{timezone}{custom}
+
+Should indicate whether this location was created by the user, though this
+always seems to be true.
+
+    $record->{timezone}{flags}
+
+Reserved flags.
+
+    $record->{timezone}{start_hour}
+    $record->{timezone}{start_daynum}
+    $record->{timezone}{start_weeknum}
+    $record->{timezone}{start_month}
+    $record->{timezone}{end_hour}
+    $record->{timezone}{end_daynum}
+    $record->{timezone}{end_weeknum}
+    $record->{timezone}{end_month}
+
+These define the period during which daylight savings time is in effect
+if $record->{timezone}{dst_adjustment} is non-zero.
+daynum specifies the day of week (0=Sunday, 6=Saturday) and weeknum specifies the week of month
+(0=1st, 3=4th, 4=last), analagously to the "monthly by day" repeating event.
+I<e.g.>, The "London" time zone has DST starting on the last Sunday of March, which
+is indicated with start_daynum=0 (Sunday), start_weeknum=4 (last week of the month),
+and start_month=3 (March).
+
+=head1 METHODS
+
+=head2 new
+
+  $pdb = new Palm::Datebook;
+  $pdb = new Palm::Datebook({app => 'Calendar'});
+
+Create a new PDB, initialized with the various Palm::Datebook fields
+and an empty record list. Creates a Datebook PDB by default.
+Specify the app parameter as 'Calendar' to create a Calendar PDB.
+
+=head2 new_Record
+
+  $record = $pdb->new_Record;
+
+Creates a new Datebook record, with blank values for all of the fields.
+
+C<new_Record> does B<not> add the new record to C<$pdb>. For that,
+you want C<< $pdb->append_Record >>.
 
 =head1 SEE ALSO
 
-Palm::PDB(3)
+L<Palm::PDB>
 
-Palm::StdAppInfo(3)
+L<Palm::StdAppInfo>
+
+=head1 CONFIGURATION AND ENVIRONMENT
+
+Palm::Datebook requires no configuration files or environment variables.
+
+=head1 INCOMPATIBILITIES
+
+None reported.
+
+=head1 BUGS AND LIMITATIONS
+
+No bugs have been reported.
+
+=head1 AUTHOR
+
+Andrew Arensburger C<< <arensb AT ooblick.com> >>
+
+Currently maintained by Christopher J. Madsen C<< <perl AT cjmweb.net> >>
+
+Please report any bugs or feature requests
+to S<C<< <bug-Palm AT rt.cpan.org> >>>
+or through the web interface at
+L<< http://rt.cpan.org/Public/Bug/Report.html?Queue=Palm >>.
+
+You can follow or contribute to p5-Palm's development at
+L<< https://github.com/madsen/p5-Palm >>.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2003 by Andrew Arensburger & Alessandro Zummo.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=head1 DISCLAIMER OF WARRANTY
+
+BECAUSE THIS SOFTWARE IS LICENSED FREE OF CHARGE, THERE IS NO WARRANTY
+FOR THE SOFTWARE, TO THE EXTENT PERMITTED BY APPLICABLE LAW. EXCEPT WHEN
+OTHERWISE STATED IN WRITING THE COPYRIGHT HOLDERS AND/OR OTHER PARTIES
+PROVIDE THE SOFTWARE "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER
+EXPRESSED OR IMPLIED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
+WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE. THE
+ENTIRE RISK AS TO THE QUALITY AND PERFORMANCE OF THE SOFTWARE IS WITH
+YOU. SHOULD THE SOFTWARE PROVE DEFECTIVE, YOU ASSUME THE COST OF ALL
+NECESSARY SERVICING, REPAIR, OR CORRECTION.
+
+IN NO EVENT UNLESS REQUIRED BY APPLICABLE LAW OR AGREED TO IN WRITING
+WILL ANY COPYRIGHT HOLDER, OR ANY OTHER PARTY WHO MAY MODIFY AND/OR
+REDISTRIBUTE THE SOFTWARE AS PERMITTED BY THE ABOVE LICENSE, BE
+LIABLE TO YOU FOR DAMAGES, INCLUDING ANY GENERAL, SPECIAL, INCIDENTAL,
+OR CONSEQUENTIAL DAMAGES ARISING OUT OF THE USE OR INABILITY TO USE
+THE SOFTWARE (INCLUDING BUT NOT LIMITED TO LOSS OF DATA OR DATA BEING
+RENDERED INACCURATE OR LOSSES SUSTAINED BY YOU OR THIRD PARTIES OR A
+FAILURE OF THE SOFTWARE TO OPERATE WITH ANY OTHER SOFTWARE), EVEN IF
+SUCH HOLDER OR OTHER PARTY HAS BEEN ADVISED OF THE POSSIBILITY OF
+SUCH DAMAGES.
 
 =cut
